/*
 * Memory Setup stuff - taken from Cirrus Logic EP9312 spec Revision 0.14
 *
 * Copyright (C) 2002 2003  Adam Bezanson, Network Audio Technologies, Inc.
 *           (bezanson@netaudiotech.com)
 *
 * See file CREDITS for list of people who contributed to this
 * project.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */



#include <config.h>
#include <version.h>
#include <ep93xx.h>

/* Include SDRAM stuff */
#include "sdramcfg.S"

	
	
.globl lowlevel_init
lowlevel_init:

	// 
        // Make sure caches are off
        //
        ldr     r1,=0
        mcr     p15,0,r1,c1,c0,0
        nop
        nop
        nop
        nop

        //
        // Go back to running from the external clock.
        //
        ldr     r1, = EP9312_CLKSET1
        mov     r0, #0
        str     r0, [r1]
        nop
        nop
        nop
        nop
        nop
            
        // 
        // Turn off both LEDs
        // 
        ldr     r1, =EP9312_LED_DATA
        ldr     r0, [r1]

	mov	r3, #0x80000000		/* I/O base */

	/* GPIO */
	orr	r0, r3, #0x840000
	mov	r1, #0x12
	str	r1, [r0, #0x04] /* PBDR  0x02:RY_ON 0x10:BBACKLIGHT*/
	mov	r1, #0x32
	str	r1, [r0, #0x14] /* PBDDR 0x32 */
#ifdef CONFIG_HW_WATCHDOG
	mov	r1, #0x40	/* Watch dog start */
#else
	mov	r1, #0x00
#endif
	str	r1, [r0, #0x40] /* PHDR 0x00 */
	mov	r1, #0x7C
	str	r1, [r0, #0x44] /* PHDDR 0x7C */

	/* Setting up flash at CS6 0x2A004d23*/
	orr	r0, r3, #0x080000
	mov	r1, #0x2A000000
	orr	r1, r1, #0x4d00
	orr	r1, r1, #0x23
	str	r1, [r0, #0x18]

	/* seting up UART 0*/
	orr	r0, r3, #0x930000
	mov	r2, #0xaa
	str	r2, [r0, #0xc0]
	ldr	r1, [r0, #0x04]
	orr	r1, r1, #0x20000000
	str	r1, [r0, #0x04]

	/* seting up  DevConfig */
	str	r2, [r0, #0xc0]
	ldr	r1, =0x0B140D10
	str	r1, [r0, #0x80]

        //
        // Turn off auto-precharge.
        //
        ldr     r1, =EP9312_SDRAMCTRL
        ldr     r0, [r1,#EP9312_SDRAMCTRL_DEVCFG_3]
        bic     r0, r0, #EP9312_SDRAMCTRL_DEVCFG_AUTOPRE
        str     r0, [r1,#EP9312_SDRAMCTRL_DEVCFG_3]
            
        // 
        // Turn off the Green LED and leave the Red LED on.
        //
        ldr     r1, =EP9312_LED_DATA
        mov     r0, #(EP9312_LED_RED_ON)
        str     r0, [r1]


        //
        // Need to make sure that SDRAM is configured correctly before
        // coping the code into it.
        //
        SdramCfg
        nop
        nop
        nop
        nop

        // 
        // Turn on Green LED, Turn off the Red LED.
        //
        ldr     r1, =EP9312_LED_DATA
        mov     r0, #(EP9312_LED_GREEN_ON)
        strb    r0,[r1]                                     
				

	/* Setting up CLKSET1 */
	orr	r0, r3, #0x930000
	mov	r1, #0x02000000
	orr	r1, r1, #0xa40000
	orr	r1, r1, #0xa300
	orr	r1, r1, #0xd7
	str	r1, [r0, #0x20]
	nop
	nop
	nop
	nop
	nop

	/* Setting up CLKSET2 */
	mov	r1, #0x30000000
	orr	r1, r1, #0x0d0000
	orr	r1, r1, #0xc300
	orr	r1, r1, #0x17
	str	r1, [r0, #0x24]
	nop
	nop
	nop
	nop
	nop
	
	/* Go to Async mode */
	mrc	p15, 0, r1, c1, c0, 0
	orr	r1, r1, #0xc0000000
	mcr	p15, 0, r1, c1, c0, 0
	mov	r1, #80
1:	subs	r1, r1, #1
	bne	1b

	mov pc,lr
