/* vim: set ts=8 sw=8 noet: */
/*
 * (C) Copyright 2002 2003
 * Network Audio Technologies, Inc. <www.netaudiotech.com>
 * Adam Bezanson <bezanson@xxxxxxxxxxxxxxxx>
 *
 *
 * See file CREDITS for list of people who contributed to this
 * project.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

#include <common.h>
#include <ep93xx.h>
#include <i2c.h>
#include <asm/mach-types.h>
#include <linux/byteorder/swab.h>

extern int sflash_print_info(void);
extern unsigned long sflash_init(void);

#define HAL_WRITE_UINT32( _register_, _value_ ) \
	(*((volatile unsigned long *)(_register_)) = (_value_))

/* ------------------------------------------------------------------------- */

/*
 * static inline void delay (unsigned long loops)
 * {
 *	__asm__ volatile ("1:\n"
 *	 "subs %0, %1, #1\n"
 *	 "bne 1b":"=r" (loops):"0" (loops));
 * }
 */

/*
 * Miscellaneous platform dependent initialisations
 */


int board_init (void)
{
    DECLARE_GLOBAL_DATA_PTR;
    char mac[6];

    icache_enable();

#ifdef USE_920T_MMU
    dcache_enable();
#endif

    GPIO_PADR = 0x00;
    GPIO_PADDR = 0x00;
    GPIO_PBDR = 0x12; /* RY_ON BBACKLIGHT*/
    GPIO_PBDDR = 0x32;
    GPIO_PCDR = 0x00;
    GPIO_PCDDR = 0xFF;
    GPIO_PDDR = 0x00;
    GPIO_PDDDR = 0xFF;
    GPIO_PEDR = 0x00;
    GPIO_PEDDR = 0x03;
    GPIO_PFDDR = 0x00;
    GPIO_PGDR = 0x00;
    GPIO_PGDDR = 0x05;
    GPIO_PHDR = 0x00;
    GPIO_PHDDR = 0x7C;

    /* Machine number, as defined in linux/arch/arm/tools/mach-types */
    gd->bd->bi_arch_number = MACH_TYPE_TB0319;

    /* adress of boot parameters */
    gd->bd->bi_boot_params = CONFIG_BOOT_PARAM_ADDR;

    /* We have a console */
    gd->have_console = 1;

    i2c_init (CFG_I2C_SPEED, CFG_I2C_SLAVE);
    sflash_init();
    return(0);
}

int misc_init_r()
{
	DECLARE_GLOBAL_DATA_PTR;
	int magic;
	char mac[6];
	sflash_init();
	if ( eeprom_read (CFG_DEF_EEPROM_ADDR, 0x1000, (char*)&magic, sizeof(magic) ) == 0 &&
	     magic == 0x43414d45 )
	{
	    eeprom_read (CFG_DEF_EEPROM_ADDR, 0x1004, mac, sizeof(mac) );
	    memcpy (gd->bd->bi_enetaddr, mac, 6);
	} else {
	    printf( "Warning: eeprom does not have valid contents.\n" );
	}
	return(0);
}

int dram_init (void)
{
	DECLARE_GLOBAL_DATA_PTR;

	gd->bd->bi_dram[0].start = PHYS_SDRAM_1;
	gd->bd->bi_dram[0].size = get_ram_size(PHYS_SDRAM_1, PHYS_SDRAM_SIZE_1);
	gd->bd->bi_dram[1].start = PHYS_SDRAM_2;
	gd->bd->bi_dram[1].size = get_ram_size(PHYS_SDRAM_2, PHYS_SDRAM_SIZE_2);

	return(0);
}

void hw_watchdog_reset(void)
{
	GPIO_PHDR ^= 0x40;
}

